/*** MODULEINFO
        <defaultenabled>no</defaultenabled>
        <support_level>core</support_level>
 ***/

#include "asterisk.h"

#include "asterisk/logger.h"
#include "asterisk/event.h"
#include "asterisk/devicestate.h"
#include "asterisk/module.h"

static struct ast_event_sub *sub;

static void event_cb(const struct ast_event *event, void *unused)
{
        int oldmsgs;
        int newmsgs;
        const char *mailbox;
        const char *context;

        newmsgs = ast_event_get_ie_uint(event, AST_EVENT_IE_NEWMSGS);
        oldmsgs = ast_event_get_ie_uint(event, AST_EVENT_IE_OLDMSGS);
        mailbox = ast_event_get_ie_str(event, AST_EVENT_IE_MAILBOX);
        context = ast_event_get_ie_str(event, AST_EVENT_IE_CONTEXT);

        if (oldmsgs + newmsgs > 0) {
                ast_debug(1, "Sending inuse devstate change for MWI:%s@%s\n", mailbox, context);
                ast_devstate_changed(AST_DEVICE_INUSE, AST_DEVSTATE_CACHABLE, "MWI:%s@%s", mailbox, context);
        } else {
                ast_debug(1, "Sending not inuse devstate change for MWI:%s@%s\n", mailbox, context);
                ast_devstate_changed(AST_DEVICE_NOT_INUSE, AST_DEVSTATE_CACHABLE, "MWI:%s@%s", mailbox, context);
        }
}

static int unload_module(void)
{
        sub = ast_event_unsubscribe(sub);
        return 0;
}

static int load_module(void)
{
        sub = ast_event_subscribe(AST_EVENT_MWI, event_cb, "MWI BLF Subscription",
                        NULL, AST_EVENT_IE_END);
        if (!sub) {
                ast_log(LOG_ERROR, "Unable to subscribe to MWI events for BLF notifications\n");
                return AST_MODULE_LOAD_DECLINE;
        }
        return AST_MODULE_LOAD_SUCCESS;
}

AST_MODULE_INFO_STANDARD(ASTERISK_GPL_KEY, "MWI BLF Subscriptions");
